.. _django_request_signer:

*********************
Django Request Signer
*********************

for documentation, please `read the docs <http://readthedocs.org/docs/django-request-signer/en/latest/index.html>`_
